@@ -11,6 +11,7 @@
 
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE FlexibleContexts #-}
+{-# LANGUAGE NoImplicitPrelude #-}
 #if __GLASGOW_HASKELL__ >= 704
 {-# LANGUAGE Safe #-}
 #endif
@@ -22,14 +23,21 @@ module Test.SmallCheck.Drivers (
   PropertyFailure(..), PropertySuccess(..), Argument, Reason, TestQuality(..)
   ) where
 
-import Control.Monad (when)
+import Control.Monad (when, return)
+import Data.Function (($), (.), const)
+import Data.IORef (readIORef, writeIORef, IORef, newIORef) -- NB: explicit import list to avoid name clash with modifyIORef'
+import Data.Maybe (Maybe(Nothing, Just))
+import Data.Ord ((>))
+import Prelude (Integer, (+), seq)
+import System.IO (IO, putStrLn)
 import Test.SmallCheck.Property
 import Test.SmallCheck.Property.Result
 import Text.Printf (printf)
-import Data.IORef (readIORef, writeIORef, IORef, newIORef) -- NB: explicit import list to avoid name clash with modifyIORef'
 
 -- | A simple driver that runs the test in the 'IO' monad and prints the
 -- results.
+--
+-- @since 1.0
 smallCheck :: Testable IO a => Depth -> a -> IO ()
 smallCheck d a = do
   ((good, bad), mbEx) <- runTestWithStats d a
@@ -73,6 +81,8 @@ modifyIORef' ref f = do
 -- * You need to run a test in a monad different from 'IO'
 --
 -- * You need to analyse the results rather than just print them
+--
+-- @since 1.0
 smallCheckM :: Testable m a => Depth -> a -> m (Maybe PropertyFailure)
 smallCheckM d = smallCheckWithHook d (const $ return ())
 
@@ -81,5 +91,7 @@ smallCheckM d = smallCheckWithHook d (const $ return ())
 --
 -- Useful for applications that want to report progress information to the
 -- user.
+--
+-- @since 1.0
 smallCheckWithHook :: Testable m a => Depth -> (TestQuality -> m ()) -> a -> m (Maybe PropertyFailure)
 smallCheckWithHook d hook a = runProperty d hook $ test a
