@@ -1,12 +1,19 @@
+{-# LANGUAGE CPP #-}
+{-# LANGUAGE NoImplicitPrelude #-}
+#if __GLASGOW_HASKELL__ >= 704
 {-# LANGUAGE Safe #-}
+#endif
 
 module Test.SmallCheck.SeriesMonad where
 
-import Control.Applicative (Applicative(..), Alternative(..), (<$>))
-import Control.Monad (MonadPlus(..))
-import Control.Monad.Logic (MonadLogic(..), LogicT)
-import Control.Monad.Reader (MonadTrans(..), ReaderT, runReaderT)
+import Control.Applicative (Applicative, Alternative, (<$>), pure, (<*>), empty, (<|>))
 import Control.Arrow (second)
+import Control.Monad (Monad, (>>=), return, MonadPlus, mzero, mplus)
+import Control.Monad.Logic (MonadLogic, LogicT, msplit)
+import Control.Monad.Reader (MonadTrans, ReaderT, runReaderT, lift)
+import Data.Function ((.), ($))
+import Data.Functor (Functor, fmap)
+import Data.Int (Int)
 
 -- | Maximum depth of generated test values.
 --
@@ -14,24 +21,28 @@ import Control.Arrow (second)
 --
 -- For functional values, it is both the depth of nested case analysis
 -- and the depth of results.
+--
+-- @since 0.6
 type Depth = Int
 
 -- | 'Series' is a `MonadLogic` action that enumerates values of a certain
 -- type, up to some depth.
 --
--- The depth bound is tracked in the 'SC' monad and can be extracted using
--- 'getDepth' and changed using 'localDepth'.
+-- The depth bound is tracked in the 'Series' monad and can be extracted using
+-- 'Test.SmallCheck.Series.getDepth' and changed using 'Test.SmallCheck.Series.localDepth'.
 --
 -- To manipulate series at the lowest level you can use its 'Monad',
 -- 'MonadPlus' and 'MonadLogic' instances. This module provides some
 -- higher-level combinators which simplify creating series.
 --
 -- A proper 'Series' should be monotonic with respect to the depth — i.e.
--- @localDepth (+1) s@ should emit all the values that @s@ emits (and
+-- 'Test.SmallCheck.Series.localDepth' @(+1)@ @s@ should emit all the values that @s@ emits (and
 -- possibly some more).
 --
 -- It is also desirable that values of smaller depth come before the values
 -- of greater depth.
+--
+-- @since 1.0
 newtype Series m a = Series (ReaderT Depth (LogicT m) a)
 
 instance Functor (Series m) where
